UserProvidedEmbedder class

Inheritance

Constructors

UserProvidedEmbedder({required int dimensions, DistributionShift? distribution, bool? binaryQuantized})
const
UserProvidedEmbedder.fromMap(Map<String, Object?> map)
factory

Properties

binaryQuantized bool?
final
dimensions int
final
distribution DistributionShift?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

source → const String