MeiliValueOperandOperatorExpressionBase class abstract
Represents an operator that has a value as an operand
- Inheritance
-
- Object
- MeiliExpressionBase
- MeiliOperatorExpressionBase
- MeiliValueOperandOperatorExpressionBase
- Implementers
- Available extensions
Constructors
- MeiliValueOperandOperatorExpressionBase({required MeiliAttributeExpression property, required MeiliValueExpressionBase value})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operator → String
-
no setter
- property → MeiliAttributeExpression
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → MeiliValueExpressionBase
-
final
Methods
-
and(
MeiliOperatorExpressionBase other) → MeiliAndOperatorExpression -
Available on MeiliOperatorExpressionBase, provided by the MeiliFiltersOperatorsExt extension
-
andList(
List< MeiliOperatorExpressionBase> others) → MeiliAndOperatorExpression -
Available on MeiliOperatorExpressionBase, provided by the MeiliFiltersOperatorsExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
not(
) → MeiliNotOperatorExpression -
Available on MeiliOperatorExpressionBase, provided by the MeiliFiltersOperatorsExt extension
-
or(
MeiliOperatorExpressionBase other) → MeiliOrOperatorExpression -
Available on MeiliOperatorExpressionBase, provided by the MeiliFiltersOperatorsExt extension
-
orList(
List< MeiliOperatorExpressionBase> others) → MeiliOrOperatorExpression -
Available on MeiliOperatorExpressionBase, provided by the MeiliFiltersOperatorsExt extension
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
) → String -
override
Operators
-
operator &(
MeiliOperatorExpressionBase other) → MeiliAndOperatorExpression -
inherited
-
operator ==(
Object other) → bool -
Fallback equality and hashing, override these when possible to optimize performance
inherited
-
operator |(
MeiliOperatorExpressionBase other) → MeiliOrOperatorExpression -
inherited
-
operator ~(
) → MeiliNotOperatorExpression -
inherited